package com.link.core.util;

import com.link.core.basic.model.BasicModel;
import com.link.core.basic.query.Filter;
import com.link.core.basic.query.QueryParams;
import com.link.core.basic.query.Sorter;
import com.link.core.basic.service.BasicServiceException;
import java.util.List;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class QueryParamUtil {
   private static final Logger logger = LogManager.getLogger(QueryParamUtil.class);

   public static BasicModel addQpsFilter(Class<? extends BasicModel> modelType, boolean pageFlag, Filter... filterArrays) {
      QueryParams qps = new QueryParams();
      qps.setPageFlag(pageFlag);
      Filter[] obj = filterArrays;
      int var5 = filterArrays.length;

      for(int var6 = 0; var6 < var5; ++var6) {
         Filter filterMap = obj[var6];
         qps.addFilter(filterMap);
      }

      obj = null;

      BasicModel obj;
      try {
         obj = (BasicModel)modelType.newInstance();
      } catch (InstantiationException var8) {
         logger.error("QueryParamUtil: ", var8);
         throw new BasicServiceException("实例化失败");
      } catch (IllegalAccessException var9) {
         logger.error("QueryParamUtil: ", var9);
         throw new BasicServiceException("生成QueryParams失败");
      }

      obj = BasicModel.transformClass(obj, qps);
      return obj;
   }

   public static BasicModel addQpsFilter(Class<? extends BasicModel> modelType, Filter... filterArrays) {
      BasicModel basicModel = addQpsFilter(modelType, false, filterArrays);
      return basicModel;
   }

   public static BasicModel addQpsFilter(Class<? extends BasicModel> modelType, List<Filter> filterArrays) {
      BasicModel basicModel = addQpsFilter(modelType, false, (Filter[])filterArrays.toArray(new Filter[0]));
      return basicModel;
   }

   public static BasicModel addQpsFilterWithSort(Class<? extends BasicModel> modelType, boolean pageFlag, Sorter sorter, Filter... filterArrays) {
      QueryParams qps = new QueryParams();
      qps.setPageFlag(pageFlag);
      Filter[] obj = filterArrays;
      int var6 = filterArrays.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         Filter filterMap = obj[var7];
         qps.addFilter(filterMap);
      }

      qps.addSorter(sorter);
      obj = null;

      BasicModel obj;
      try {
         obj = (BasicModel)modelType.newInstance();
      } catch (InstantiationException var9) {
         logger.error("QueryParamUtil: ", var9);
         throw new BasicServiceException("实例化失败");
      } catch (IllegalAccessException var10) {
         logger.error("QueryParamUtil: ", var10);
         throw new BasicServiceException("生成QueryParams失败");
      }

      obj = BasicModel.transformClass(obj, qps);
      return obj;
   }

   private static <T extends BasicModel> T addGenericFilter(Class<T> modelClazz, boolean pageFlag, Filter... filters) {
      QueryParams qps = new QueryParams();
      qps.setPageFlag(pageFlag);
      Filter[] var4 = filters;
      int var5 = filters.length;

      for(int var6 = 0; var6 < var5; ++var6) {
         Filter filter = var4[var6];
         qps.addFilter(filter);
      }

      BasicModel object;
      try {
         object = (BasicModel)modelClazz.newInstance();
      } catch (InstantiationException var8) {
         logger.error("QueryParamUtil: ", var8);
         throw new BasicServiceException("实例化失败");
      } catch (IllegalAccessException var9) {
         logger.error("QueryParamUtil: ", var9);
         throw new BasicServiceException("生成QueryParams失败");
      }

      return BasicModel.transformClass(object, qps);
   }

   public static <T extends BasicModel> T addGenericFilter(Class<T> modelClazz, boolean pageFlag, Sorter sorter, Filter... filters) {
      QueryParams qps = new QueryParams();
      qps.setPageFlag(pageFlag);
      Filter[] var5 = filters;
      int var6 = filters.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         Filter filter = var5[var7];
         qps.addFilter(filter);
      }

      qps.addSorter(sorter);

      BasicModel object;
      try {
         object = (BasicModel)modelClazz.newInstance();
      } catch (InstantiationException var9) {
         logger.error("QueryParamUtil: ", var9);
         throw new BasicServiceException("实例化失败");
      } catch (IllegalAccessException var10) {
         logger.error("QueryParamUtil: ", var10);
         throw new BasicServiceException("生成QueryParams失败");
      }

      return BasicModel.transformClass(object, qps);
   }

   public static <T extends BasicModel> T addGenericFilterAll(Class<T> modelClazz, Filter... filters) {
      return addGenericFilter(modelClazz, false, filters);
   }
}
